@@ -38,21 +38,19 @@
 #' 
 #' @importFrom parallel mclapply
 #' 
-#' @export calc_roc calc_roc.rfsrc
 #' @examples
 #' ## Taken from the gg_roc example
 #' # rfsrc_iris <- rfsrc(Species ~ ., data = iris)
 #' data(rfsrc_iris)
 #' gg_dta <- calc_roc.rfsrc(rfsrc_iris, rfsrc_iris$yvar, which.outcome=1, oob=TRUE)
 #' gg_dta <- calc_roc.rfsrc(rfsrc_iris, rfsrc_iris$yvar, which.outcome=1, oob=FALSE)
-#' 
+#' @export
 
 calc_roc.rfsrc <- function(object, yvar, which.outcome="all", oob=TRUE){
-  
   if(!is.factor(yvar)) yvar <- factor(yvar)
-  
-  if(which.outcome!="all"){
-    dta.roc <- data.frame(cbind(res=(yvar == levels(yvar)[which.outcome]), 
+
+  if(which.outcome != "all"){
+    dta.roc <- data.frame(cbind(res=(yvar == levels(yvar)[which.outcome]),
                                 prd=object$predicted[, which.outcome],
                                 oob=object$predicted.oob[, which.outcome]))
     if(oob)
@@ -62,29 +60,29 @@ calc_roc.rfsrc <- function(object, yvar, which.outcome="all", oob=TRUE){
   }else{
     stop("Must specify which.outcome for now.")
   }
-  
-  pct<- pct[-length(pct)]
-  
+
+  pct <- pct[-length(pct)]
+
   gg_dta <- mclapply(pct, function(crit){
-    if(oob) 
-      tbl <- xtabs(~res+(oob>crit), dta.roc)
+    if(oob)
+      tbl <- xtabs(~res + (oob > crit), dta.roc)
     else
-      tbl <- xtabs(~res+(prd>crit), dta.roc)
-    
-    spec<-tbl[2,2]/rowSums(tbl)[2]
-    sens<-tbl[1,1]/rowSums(tbl)[1]
-    cbind(sens=sens,spec=spec )
+      tbl <- xtabs(~res + (prd > crit), dta.roc)
+
+    spec <- tbl[2,2] / rowSums(tbl)[2]
+    sens <- tbl[1,1] / rowSums(tbl)[1]
+    cbind(sens = sens,spec = spec )
   })
-  
+
   gg_dta <- do.call(rbind, gg_dta)
   gg_dta <- rbind(c(0,1), gg_dta, c(1,0))
-  
+
   gg_dta <- data.frame(gg_dta, row.names=1:nrow(gg_dta))
   gg_dta$pct <- c(0,pct,1)
   invisible(gg_dta)
 }
 
-calc_roc<- calc_roc.rfsrc
+calc_roc <- calc_roc.rfsrc
 
 ## This is in development still.
 ## We'll return to this when we start the next version.
@@ -122,7 +120,7 @@ calc_roc<- calc_roc.rfsrc
 #' 
 #' @return AUC. 50\% is random guessing, higher is better.
 #' 
-#' @importFrom dplyr lead
+# @importFrom dplyr lead
 #' 
 #' @seealso \code{\link{calc_roc}} \code{\link{gg_roc}} \code{\link{plot.gg_roc}}
 #' 
@@ -135,21 +133,86 @@ calc_roc<- calc_roc.rfsrc
 #' 
 #' calc_auc(gg_dta)
 #' 
-#' @export calc_auc
 #' @aliases calc_auc calc_auc.gg_roc
-#' 
+#' @export
 calc_auc <- function(x){
   ## Use the trapeziod rule, basically calc
   ##
   ## auc = dx/2(f(x_{i+1}) - f(x_i))
   ##
   ## f(x) is sensitivity, x is 1-specificity
-  
+
   # SInce we are leading vectors (x_{i+1} - x_{i}), we need to
   # ensure we are in decreasing order of specificity (x var = 1-spec)
   x <- x[order(x$spec, decreasing=TRUE),]
-  
-  auc <- (3*lead(x$sens) - x$sens)/2 * (x$spec - lead(x$spec))
+
+  auc <- (3 * shift(x$sens) - x$sens) / 2 * (x$spec - shift(x$spec))
   sum(auc, na.rm=TRUE)
 }
-calc_auc.gg_roc <- calc_auc
\ No newline at end of file
+calc_auc.gg_roc <- calc_auc
+
+#' lead function to shift by one (or more).
+#' 
+#' @param x a vector of values
+#' @param shift_by an integer of length 1, giving the number of positions 
+#' to lead (positive) or lag (negative) by
+#' 
+#' @details Lead and lag are useful for comparing values offset by a constant 
+#' (e.g. the previous or next value)
+#' 
+#' Taken from:
+#' http://ctszkin.com/2012/03/11/generating-a-laglead-variables/
+#' 
+#' This function allows me to remove the dplyr::lead depends. Still suggest for vignettes though.
+#' 
+#' @examples
+#' d<-data.frame(x=1:15) 
+#' #generate lead variable
+#' d$df_lead2<-ggRandomForests:::shift(d$x,2)
+#' #generate lag variable
+#' d$df_lag2<-ggRandomForests:::shift(d$x,-2)
+# 
+# > d
+# x df_lead2 df_lag2
+# 1   1        3      NA
+# 2   2        4      NA
+# 3   3        5       1
+# 4   4        6       2
+# 5   5        7       3
+# 6   6        8       4
+# 7   7        9       5
+# 8   8       10       6
+# 9   9       NA       7
+# 10 10       NA       8
+# 
+# # shift_by is vectorized
+# d$df_lead2 shift(d$x,-2:2)
+# [,1] [,2] [,3] [,4] [,5]
+# [1,]   NA   NA    1    2    3
+# [2,]   NA    1    2    3    4
+# [3,]    1    2    3    4    5
+# [4,]    2    3    4    5    6
+# [5,]    3    4    5    6    7
+# [6,]    4    5    6    7    8
+# [7,]    5    6    7    8    9
+# [8,]    6    7    8    9   10
+# [9,]    7    8    9   10   NA
+# [10,]    8    9   10   NA   NA
+
+shift <- function(x,shift_by=1){
+  stopifnot(is.numeric(shift_by))
+  stopifnot(is.numeric(x))
+
+  if (length(shift_by) > 1)
+    return(sapply(shift_by,shift, x=x))
+
+  out <- NULL
+  abs_shift_by <- abs(shift_by)
+  if (shift_by > 0 )
+    out <- c(tail(x,-abs_shift_by),rep(NA,abs_shift_by))
+  else if (shift_by < 0 )
+    out <- c(rep(NA, abs_shift_by), head(x,-abs_shift_by))
+  else
+    out <- x
+  out
+}
\ No newline at end of file
